This is a module of the PythonVideoAnnotator application.

You can find the documentation for this module as well as for the PythonVideoAnnotator application here:

https://pythonvideoannotator.readthedocs.io/en/master/